@@ -52,10 +52,6 @@ static GPrivate local_connections = G_PRIVATE_INIT((GDestroyNotify)free_local_co
 static GHashTable *async_map = NULL;
 G_LOCK_DEFINE_STATIC(async_map);
 
-/* dbus object path -> dbus message filter */
-static GHashTable *obj_path_map = NULL;
-G_LOCK_DEFINE_STATIC(obj_path_map);
-
 
 GQuark
 _g_vfs_error_quark (void)
@@ -63,110 +59,6 @@ _g_vfs_error_quark (void)
   return g_quark_from_static_string ("g-vfs-error-quark");
 }
 
-/**************************************************************************
- *               message filters for vfs dbus connections                 *
- *************************************************************************/
-
-typedef struct {
-  GVfsRegisterVfsFilterCallback callback;
-  GObject *data;
-  GHashTable *skeletons;
-} PathMapEntry;
-
-static void
-free_path_map_entry (PathMapEntry *entry)
-{
-  g_hash_table_destroy (entry->skeletons);
-  g_free (entry);
-}
-
-static void
-unref_skeleton (gpointer object)
-{
-  GDBusInterfaceSkeleton *skeleton = object;
-
-  g_dbus_interface_skeleton_unexport (skeleton);
-  g_object_unref (skeleton);
-}
-
-/*  Please note the obj_path has to be unique even for different interfaces  */
-void
-_g_dbus_register_vfs_filter (const char *obj_path,
-                             GVfsRegisterVfsFilterCallback callback,
-			     GObject *data)
-{
-  PathMapEntry *entry;
-
-  G_LOCK (obj_path_map);
-  
-  if (obj_path_map == NULL)
-    obj_path_map = g_hash_table_new_full (g_str_hash, g_str_equal,
-					  g_free, (GDestroyNotify)free_path_map_entry);
-
-  entry = g_new (PathMapEntry, 1);
-  entry->callback = callback;
-  entry->data = data;
-  entry->skeletons = g_hash_table_new_full (g_direct_hash, g_direct_equal, NULL, (GDestroyNotify)unref_skeleton);
-
-  g_hash_table_insert (obj_path_map, g_strdup (obj_path), entry);
-  
-  G_UNLOCK (obj_path_map);
-}
-
-void
-_g_dbus_unregister_vfs_filter (const char *obj_path)
-{
-  G_LOCK (obj_path_map);
-
-  if (obj_path_map)
-      g_hash_table_remove (obj_path_map, obj_path);
-  
-  G_UNLOCK (obj_path_map);
-}
-
-static void
-register_skeleton (const char *obj_path,
-                   PathMapEntry *entry,
-                   GDBusConnection *dbus_conn)
-{
-  GDBusInterfaceSkeleton *skeleton;
-
-  if (! g_hash_table_contains (entry->skeletons, dbus_conn))
-    {
-      /* Note that the newly created GDBusInterfaceSkeleton instance refs the connection so it's not needed to watch for connection being destroyed */ 
-      skeleton = entry->callback (dbus_conn, obj_path, entry->data);
-      g_hash_table_insert (entry->skeletons, dbus_conn, skeleton);
-    }
-  else
-    {
-      /* Interface skeleton has already been registered on the connection, skipping */
-    }
-}
-
-/*
- *  Export registered interface skeletons on this connection. This should ideally
- *  be called only once for every connection, but we often share/reuse existing
- *  connections.
- *  
- *  Already exported interface skeletons should live as long as possible
- *  since there might be ongoing data transfer and re-exporting (unreffing + creation)
- *  breaks running jobs randomly.
- *  
- */
-void
-_g_dbus_connect_vfs_filters (GDBusConnection *connection)
-{
-  G_LOCK (obj_path_map);
-
-  if (obj_path_map)
-    {
-      /* Export new interface skeletons */
-      g_hash_table_foreach (obj_path_map, (GHFunc) register_skeleton, connection);
-    }
-
-  G_UNLOCK (obj_path_map);
-}
-
 static void
 connection_data_free (gpointer p)
 {
