@@ -998,6 +998,9 @@ open_common (const gchar *path, struct fuse_file_info *fi, GFile *file, int outp
   else
     result = setup_input_stream (file, fh);
 
+  if (fh->stream)
+    fi->nonseekable = !g_seekable_can_seek (G_SEEKABLE (fh->stream));
+
   g_mutex_unlock (&fh->mutex);
 
   /* The added reference to the file handle is released in vfs_release() */
@@ -1198,7 +1201,7 @@ read_stream (FileHandle *fh, gchar *output_buf, size_t output_buf_size, off_t of
           if (n_bytes_skipped > 0)
             fh->pos += n_bytes_skipped;
 
-          if (n_bytes_skipped != offset - fh->pos)
+          if (offset != fh->pos)
             {
               if (error)
                 {
@@ -2391,6 +2394,9 @@ vfs_init (struct fuse_conn_info *conn)
   /* Indicate O_TRUNC support for open() */
   conn->want |= FUSE_CAP_ATOMIC_O_TRUNC;
 
+  /* Prevent out-of-order readahead */
+  conn->async_read = 0;
+
   return NULL;
 }
 
