@@ -359,8 +359,7 @@ _idevice_event_cb (const idevice_event_t *event, void *user_data)
 
   idevice_event_unsubscribe ();
 
-  /* TODO: need a cleaner way to force unmount ourselves */
-  exit (1);
+  g_vfs_backend_force_unmount ((GVfsBackend*)afc_backend);
 }
 
 static gboolean
@@ -808,6 +807,7 @@ g_vfs_backend_setup_afc_for_app (GVfsBackendAfc *self,
       g_warning ("Failed to get a lockdown to start house arrest for app %s", info->id);
       return;
     }
+
   lerr = lockdownd_start_service (lockdown_cli, "com.apple.mobile.house_arrest", &lockdown_service);
   if (lerr != LOCKDOWN_E_SUCCESS)
     {
