@@ -43,10 +43,12 @@
 #define NETWORK_FILE_ATTRIBUTES "standard::name,standard::display-name,standard::target-uri"
 
 typedef struct {
-  char *file_name; 
+  char *file_name;
   char *display_name;
   char *target_uri;
   GIcon *icon;
+  GIcon *symbolic_icon;
+  guint num_duplicates;
 } NetworkFile;
 
 static NetworkFile root = { "/" };
@@ -77,6 +79,8 @@ struct _GVfsBackendNetwork
   /* Icons */
   GIcon *workgroup_icon; /* GThemedIcon = "network-workgroup" */
   GIcon *server_icon; /* GThemedIcon = "network-server" */
+  GIcon *workgroup_symbolic_icon; /* GThemedIcon = "network-workgroup-symbolic" */
+  GIcon *server_symbolic_icon; /* GThemedIcon = "network-server-symbolic" */
 };
 
 typedef struct _GVfsBackendNetwork GVfsBackendNetwork;
@@ -87,7 +91,8 @@ static NetworkFile *
 network_file_new (const char *file_name, 
                   const char *display_name, 
                   const char *target_uri, 
-                  GIcon *icon)
+                  GIcon      *icon,
+                  GIcon      *symbolic_icon)
 {
   NetworkFile *file;
   
@@ -97,6 +102,7 @@ network_file_new (const char *file_name,
   file->display_name = g_strdup (display_name);
   file->target_uri = g_strdup (target_uri);
   file->icon = g_object_ref (icon);
+  file->symbolic_icon = g_object_ref (symbolic_icon);
 
   return file;
 }
@@ -110,6 +116,8 @@ network_file_free (NetworkFile *file)
  
   if (file->icon)
     g_object_unref (file->icon);
+  if (file->symbolic_icon)
+    g_object_unref (file->symbolic_icon);
 
   g_slice_free (NetworkFile, file);
 }
@@ -122,6 +130,8 @@ network_file_equal (NetworkFile *a,
 {
   if (!g_icon_equal (a->icon, b->icon))
     return FALSE;
+  if (!g_icon_equal (a->symbolic_icon, b->symbolic_icon))
+    return FALSE;
 
   if ((a->display_name != NULL && b->display_name == NULL) ||
       (a->display_name == NULL && b->display_name != NULL))
@@ -140,6 +150,79 @@ sort_file_by_file_name (NetworkFile *a, NetworkFile *b)
   return strcmp (a->file_name, b->file_name);
 }
 
+static char *
+get_pretty_scheme_for_uri (const char *uri)
+{
+  GFile *file;
+  char *scheme;
+  char *pretty = NULL;
+
+  file = g_file_new_for_uri (uri);
+  if (file == NULL)
+    return NULL;
+
+  scheme = g_file_get_uri_scheme (file);
+  if (g_strcmp0 (scheme, "afp") == 0
+      || g_strcmp0 (scheme, "smb") == 0)
+    {
+      pretty = g_strdup (_("File Sharing"));
+    }
+  else if (g_strcmp0 (scheme, "sftp") == 0
+           || g_strcmp0 (scheme, "ssh") == 0)
+    {
+      pretty = g_strdup (_("Remote Login"));
+    }
+  else
+    {
+      pretty = g_strdup (scheme);
+    }
+
+  g_free (scheme);
+
+  return pretty;
+}
+
+static void
+network_file_append_service_name (NetworkFile *file)
+{
+  char *name;
+  char *service;
+
+  service = get_pretty_scheme_for_uri (file->target_uri);
+  name = g_strdup_printf ("%s (%s)", file->display_name, service);
+  g_free (service);
+  g_free (file->display_name);
+  file->display_name = name;
+}
+
+static void
+uniquify_display_names (GVfsBackendNetwork *backend)
+{
+  GHashTable *names;
+  GList *l;
+
+  names = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
+
+  for (l = backend->files; l != NULL; l = l->next)
+    {
+      NetworkFile *prev_file;
+      NetworkFile *file = l->data;
+
+      prev_file = g_hash_table_lookup (names, file->display_name);
+      if (prev_file != NULL)
+        {
+          prev_file->num_duplicates++;
+          /* only change the first file once */
+          if (prev_file->num_duplicates == 1)
+            network_file_append_service_name (prev_file);
+          network_file_append_service_name (file);
+        }
+      g_hash_table_replace (names, g_strdup (file->display_name), file);
+    }
+
+  g_hash_table_destroy (names);
+}
+
 static void
 update_from_files (GVfsBackendNetwork *backend,
                    GList *files)
@@ -153,6 +236,8 @@ update_from_files (GVfsBackendNetwork *backend,
   old_files = backend->files;
   backend->files = g_list_sort (files, (GCompareFunc)sort_file_by_file_name);
 
+  uniquify_display_names (backend);
+
   /* Generate change events */
   oldl = old_files;
   newl = backend->files;
@@ -244,8 +329,11 @@ recompute_files (GVfsBackendNetwork *backend)
       char *workgroup;
       
       /* smb:/// root link */
-      file = network_file_new ("smb-root", _("Windows Network"), 
-                               "smb:///", backend->workgroup_icon);
+      file = network_file_new ("smb-root",
+                               _("Windows Network"),
+                               "smb:///",
+                               backend->workgroup_icon,
+                               backend->workgroup_symbolic_icon);
       files = g_list_prepend (files, file);
 
       if (backend->current_workgroup == NULL ||
@@ -293,7 +381,8 @@ recompute_files (GVfsBackendNetwork *backend)
               file = network_file_new (file_name, 
                                        g_file_info_get_display_name (info), 
                                        link_uri, 
-                                       backend->server_icon);
+                                       backend->server_icon,
+                                       backend->server_symbolic_icon);
               files = g_list_prepend (files, file);
 
               g_free (link_uri);
@@ -351,8 +440,9 @@ recompute_files (GVfsBackendNetwork *backend)
                                       "standard::target-uri"));
                   file = network_file_new (file_name, 
 					   g_file_info_get_display_name (info), 
-					   link_uri, 
-					   backend->server_icon);
+					   link_uri,
+					   backend->server_icon,
+					   backend->server_symbolic_icon);
                   files = g_list_prepend (files, file);
 		  
                   g_free (link_uri);
@@ -368,8 +458,11 @@ recompute_files (GVfsBackendNetwork *backend)
       else
         {
           /* "separate": a link to dns-sd://local/ */
-          file = network_file_new ("dnssd-local", _("Local Network"), 
-				   "dns-sd://local/", backend->workgroup_icon);
+          file = network_file_new ("dnssd-local",
+                                   _("Local Network"),
+				   "dns-sd://local/",
+                                   backend->workgroup_icon,
+                                   backend->workgroup_symbolic_icon);
           files = g_list_prepend (files, file);   
         }
       
@@ -390,7 +483,8 @@ recompute_files (GVfsBackendNetwork *backend)
 	      file = network_file_new (file_name,
 				       domains[i],
 				       link_uri,
-				       backend->workgroup_icon);
+				       backend->workgroup_icon,
+				       backend->workgroup_symbolic_icon);
 	      files = g_list_prepend (files, file);   
 	      g_free (link_uri);
 	      g_free (file_name);
@@ -616,9 +710,10 @@ file_info_from_file (NetworkFile *file,
 
   if (file->icon) 
     g_file_info_set_icon (info, file->icon);
+  if (file->symbolic_icon)
+    g_file_info_set_symbolic_icon (info, file->symbolic_icon);
 
   g_file_info_set_file_type (info, G_FILE_TYPE_SHORTCUT);
-  g_file_info_set_size (info, 0);
   g_file_info_set_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE, FALSE);
   g_file_info_set_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_DELETE, FALSE);
   g_file_info_set_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_TRASH, FALSE);
@@ -689,6 +784,9 @@ try_query_info (GVfsBackend *backend,
       icon = g_themed_icon_new ("network-workgroup");
       g_file_info_set_icon (info, icon);
       g_object_unref (icon);
+      icon = g_themed_icon_new ("network-workgroup-symbolic");
+      g_file_info_set_symbolic_icon (info, icon);
+      g_object_unref (icon);
       g_file_info_set_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE, FALSE);
       g_file_info_set_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_DELETE, FALSE);
       g_file_info_set_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_TRASH, FALSE);
@@ -820,6 +918,7 @@ g_vfs_backend_network_init (GVfsBackendNetwork *network_backend)
   g_vfs_backend_set_display_name (backend, _("Network"));
   g_vfs_backend_set_stable_name (backend, _("Network"));
   g_vfs_backend_set_icon_name (backend, "network-workgroup");
+  g_vfs_backend_set_symbolic_icon_name (backend, "network-workgroup-symbolic");
   g_vfs_backend_set_user_visible (backend, FALSE);
 
   mount_spec = g_mount_spec_new ("network");
@@ -828,6 +927,8 @@ g_vfs_backend_network_init (GVfsBackendNetwork *network_backend)
 
   network_backend->workgroup_icon = g_themed_icon_new ("network-workgroup");
   network_backend->server_icon = g_themed_icon_new ("network-server");
+  network_backend->workgroup_symbolic_icon = g_themed_icon_new ("network-workgroup-symbolic");
+  network_backend->server_symbolic_icon = g_themed_icon_new ("network-server-symbolic");
 }
 
 static void
@@ -841,6 +942,8 @@ g_vfs_backend_network_finalize (GObject *object)
   g_object_unref (backend->root_monitor);
   g_object_unref (backend->workgroup_icon);
   g_object_unref (backend->server_icon);
+  g_object_unref (backend->workgroup_symbolic_icon);
+  g_object_unref (backend->server_symbolic_icon);
   if (backend->smb_settings)
     g_object_unref (backend->smb_settings);
   if (backend->dnssd_settings)
