@@ -83,7 +83,7 @@ on_name_acquired (GDBusConnection *connection,
   if (!no_fuse)
     {
       char *fuse_path;
-      char *argv2[6];
+      char *argv2[4];
       
       /* Use the old .gvfs location as fallback, not .cache/gvfs */
       if (g_get_user_runtime_dir() == g_get_user_cache_dir ())
@@ -101,11 +101,9 @@ on_name_acquired (GDBusConnection *connection,
       /* Opengroup. On system with the uClibc library this will badly */
       /* hang the process.                                            */
       argv2[0] = LIBEXEC_DIR "/gvfsd-fuse";
-      argv2[1] = fuse_path;
-      argv2[2] = "-f";
-      argv2[3] = "-o";
-      argv2[4] = "big_writes";
-      argv2[5] = NULL;
+      argv2[1] = "-f";
+      argv2[2] = fuse_path;
+      argv2[3] = NULL;
       
       g_spawn_async (NULL,
                      argv2,
@@ -120,6 +118,13 @@ on_name_acquired (GDBusConnection *connection,
 #endif
 }
 
+static void
+daemon_shutdown (GVfsDaemon *daemon,
+                 GMainLoop  *loop)
+{
+  if (g_main_loop_is_running (loop))
+    g_main_loop_quit (loop);
+}
 
 int
 main (int argc, char *argv[])
@@ -183,6 +188,9 @@ main (int argc, char *argv[])
   if (daemon == NULL)
     return 1;
 
+  g_signal_connect (daemon, "shutdown",
+		    G_CALLBACK (daemon_shutdown), loop);
+
   flags = G_BUS_NAME_OWNER_FLAGS_ALLOW_REPLACEMENT;
   if (replace)
     flags |= G_BUS_NAME_OWNER_FLAGS_REPLACE;
